<div align="center">
  <img src="https://www.frootlab.org/images/fig/aughra.svg" width=350px>
</div>

Aughra
======

[![Building Status](https://travis-ci.org/frootlab/aughra.svg?branch=master)](https://travis-ci.org/frootlab/aughra)
[![Documentation Status](https://readthedocs.org/projects/aughra/badge/?version=latest)](https://aughra.readthedocs.io/en/latest/?badge=latest)
[![PIP Version](https://badge.fury.io/py/aughra.svg)](https://badge.fury.io/py/aughra)

*Aughra* is a planned root directory for the [Vivid Code](https://www.frootlab.org/projects/vivid.html) framework.
Aughra is intended to deploy information about public [Vivid Stores](https://www.frootlab.org/projects/vivid/store.html)
to allow an automatic configuration of [Vivid Nodes](https://www.frootlab.org/projects/vivid/node.html).

Aughra is open source, based on the [Python](https://www.python.org/)
programming language and actively developed as part of the
[Vivid Code](https://www.frootlab.org/vivid) framework at
[Frootlab](https://www.frootlab.org).

Current Development Status
--------------------------

Aughra currently is in early *Planning* stage. This means, that the projects
directives, requirements and goals are mostly not yet settled or implemented.

Installation
------------

Comprehensive information and installation support is provided within the
[online manual](https://aughra.readthedocs.io/en/latest/). If you already have a
Python environment configured on your computer, you can install the latest
distributed version by using pip:

    $ pip install aughra

Documentation
-------------

The latest Aughra documentation is available as an [online
manual](https://aughra.readthedocs.io/en/latest/) and for download in the
formats [PDF](https://readthedocs.org/projects/aughra/downloads/pdf/latest/),
[EPUB](https://readthedocs.org/projects/aughra/downloads/epub/latest/) and
[HTML](https://readthedocs.org/projects/aughra/downloads/htmlzip/latest/).

Contribute
----------

Contributors are very welcome! Feel free to report bugs and feature requests to
the [issue tracker](https://github.com/frootlab/aughra/issues) provided by
GitHub. Currently, as the Frootlab Developers team still is growing, we do not
provide any Contribution Guide Lines to collaboration partners. However, if you
are interested to join the team, we would be glad, to receive an informal
[application](mailto:application@frootlab.org).

License
-------

Aughra is open source and available free for any use under the
[GPLv3](https://www.gnu.org/licenses/gpl.html) license:

    © 2019 Frootlab Developers:
      Patrick Michl <patrick.michl@frootlab.org>
